(**************************************************************************)
(*  Mana : A kana(romaji)-kanji conversion engine using ChaSen algorithm. *)
(*  Copyright (C) 2003, 2004, 2005,2006  Yamagata Yoriyuki                *)
(*                                                                        *)
(*  This program is free software; you can redistribute it and/or modify  *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation; either version 2 of the License, or (at  *)
(*  your option) any later version.                                       *)
(*                                                                        *)
(*  This program is distributed in the hope that it will be useful, but   *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of            *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *)
(*  General Public License for more details.                              *)
(**************************************************************************)

(* $Id: personalDict.mli 171 2006-04-24 15:23:30Z yori $ *)

(* [(<>,<Ǹ˻Ѥ줿Υ>)...]֤ *)
val lookup : string -> int -> int -> (Chasen.mrph * int) list

(* [(<>,<Ǹ˻Ѥ줿Υ>,<Ĺ>)...]֤ *)
val lookup_prefix : string -> int -> int -> (Chasen.mrph * int *int) list

val current_count : unit -> int

val add : Chasen.mrph -> unit
val remove : Chasen.mrph -> unit
val incr_count : Chasen.mrph -> unit
